@@ -9,7 +9,7 @@
 -- using any group of target strings. It is typically used for file
 -- name completion as is common in many UNIX shells.
 -- 
--- A @GCompletion@ is created using [func/@gLib@/.Completion.new]. Target items are
+-- A @GCompletion@ is created using t'GI.GLib.Structs.Completion.Completion'.@/new/@(). Target items are
 -- added and removed with t'GI.GLib.Structs.Completion.Completion'.@/add_items/@(),
 -- t'GI.GLib.Structs.Completion.Completion'.@/remove_items/@() and
 -- 'GI.GLib.Structs.Completion.completionClearItems'. A completion attempt is requested with
@@ -19,7 +19,7 @@
 -- 
 -- Items in the completion can be simple strings (e.g. filenames), or
 -- pointers to arbitrary data structures. If data structures are used
--- you must provide a [type/@gLib@/.CompletionFunc] in [func/@gLib@/.Completion.new],
+-- you must provide a [type/@gLib@/.CompletionFunc] in t'GI.GLib.Structs.Completion.Completion'.@/new/@(),
 -- which retrieves the item’s string from the data structure. You can change
 -- the way in which strings are compared by setting a different
 -- [type/@gLib@/.CompletionStrncmpFunc] in t'GI.GLib.Structs.Completion.Completion'.@/set_compare/@().
@@ -202,7 +202,7 @@ instance CallocPtr Completion where
     boxedPtrCalloc = callocBytes 40
 
 
--- | Construct a `Completion` struct initialized to zero.
+-- | Construct a t'Completion' struct initialized to zero.
 newZeroCompletion :: MonadIO m => m Completion
 newZeroCompletion = liftIO $ boxedPtrCalloc >>= wrapPtr Completion
 
@@ -264,7 +264,7 @@ instance AttrInfo CompletionItemsFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.items"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#g:attr:items"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#g:attr:items"
         })
 
 completion_items :: AttrLabelProxy "items"
@@ -279,7 +279,7 @@ completion_items = AttrLabelProxy
 -- @
 -- 'Data.GI.Base.Attributes.get' completion #func
 -- @
-getCompletionFunc :: MonadIO m => Completion -> m (Maybe GLib.Callbacks.CompletionFunc_WithClosures)
+getCompletionFunc :: MonadIO m => Completion -> m (Maybe GLib.Callbacks.CompletionFunc)
 getCompletionFunc s = liftIO $ withManagedPtr s $ \ptr -> do
     val <- peek (ptr `plusPtr` 8) :: IO (FunPtr GLib.Callbacks.C_CompletionFunc)
     result <- SP.convertFunPtrIfNonNull val $ \val' -> do
@@ -313,9 +313,9 @@ instance AttrInfo CompletionFuncFieldInfo where
     type AttrBaseTypeConstraint CompletionFuncFieldInfo = (~) Completion
     type AttrAllowedOps CompletionFuncFieldInfo = '[ 'AttrSet, 'AttrGet, 'AttrClear]
     type AttrSetTypeConstraint CompletionFuncFieldInfo = (~) (FunPtr GLib.Callbacks.C_CompletionFunc)
-    type AttrTransferTypeConstraint CompletionFuncFieldInfo = (~)GLib.Callbacks.CompletionFunc_WithClosures
+    type AttrTransferTypeConstraint CompletionFuncFieldInfo = (~)GLib.Callbacks.CompletionFunc
     type AttrTransferType CompletionFuncFieldInfo = (FunPtr GLib.Callbacks.C_CompletionFunc)
-    type AttrGetType CompletionFuncFieldInfo = Maybe GLib.Callbacks.CompletionFunc_WithClosures
+    type AttrGetType CompletionFuncFieldInfo = Maybe GLib.Callbacks.CompletionFunc
     type AttrLabel CompletionFuncFieldInfo = "func"
     type AttrOrigin CompletionFuncFieldInfo = Completion
     attrGet = getCompletionFunc
@@ -326,7 +326,7 @@ instance AttrInfo CompletionFuncFieldInfo where
         GLib.Callbacks.mk_CompletionFunc (GLib.Callbacks.wrap_CompletionFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.func"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#g:attr:func"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#g:attr:func"
         })
 
 completion_func :: AttrLabelProxy "func"
@@ -388,7 +388,7 @@ instance AttrInfo CompletionPrefixFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.prefix"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#g:attr:prefix"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#g:attr:prefix"
         })
 
 completion_prefix :: AttrLabelProxy "prefix"
@@ -448,7 +448,7 @@ instance AttrInfo CompletionCacheFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.cache"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#g:attr:cache"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#g:attr:cache"
         })
 
 completion_cache :: AttrLabelProxy "cache"
@@ -510,7 +510,7 @@ instance AttrInfo CompletionStrncmpFuncFieldInfo where
         GLib.Callbacks.mk_CompletionStrncmpFunc (GLib.Callbacks.wrap_CompletionStrncmpFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.strncmpFunc"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#g:attr:strncmpFunc"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#g:attr:strncmpFunc"
         })
 
 completion_strncmpFunc :: AttrLabelProxy "strncmpFunc"
@@ -577,7 +577,7 @@ instance (signature ~ (m ()), MonadIO m) => O.OverloadedMethod CompletionClearIt
 instance O.OverloadedMethodInfo CompletionClearItemsMethodInfo Completion where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.completionClearItems",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#v:completionClearItems"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#v:completionClearItems"
         })
 
 
@@ -695,7 +695,7 @@ instance (signature ~ (T.Text -> T.Text -> m [T.Text]), MonadIO m) => O.Overload
 instance O.OverloadedMethodInfo CompletionCompleteUtf8MethodInfo Completion where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.completionCompleteUtf8",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#v:completionCompleteUtf8"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#v:completionCompleteUtf8"
         })
 
 
@@ -752,7 +752,7 @@ instance (signature ~ (m ()), MonadIO m) => O.OverloadedMethod CompletionFreeMet
 instance O.OverloadedMethodInfo CompletionFreeMethodInfo Completion where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Completion.completionFree",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Completion.html#v:completionFree"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Completion.html#v:completionFree"
         })
 
 
